@@ -1,4 +1,5 @@
 """Module for all supported parameter optimization methods."""
+from tpcp.base import BaseOptimize
 from tpcp.optimize._optimize import DummyOptimize, GridSearch, GridSearchCV, Optimize
 
-__all__ = ["GridSearch", "GridSearchCV", "Optimize", "DummyOptimize"]
+__all__ = ["GridSearch", "GridSearchCV", "Optimize", "DummyOptimize", "BaseOptimize"]
