@@ -15,6 +15,7 @@ from numpy.ma import MaskedArray
 from scipy.stats import rankdata
 from sklearn.model_selection import BaseCrossValidator, ParameterGrid, check_cv
 
+from tpcp import Dataset, OptimizablePipeline, SimplePipeline
 from tpcp._utils._general import (
     _aggregate_final_results,
     _normalize_score_results,
@@ -24,9 +25,7 @@ from tpcp._utils._general import (
 from tpcp._utils._multiprocess import init_progressbar
 from tpcp._utils._score import _optimize_and_score, _score
 from tpcp.base import BaseOptimize
-from tpcp.dataset import Dataset
 from tpcp.exceptions import PotentialUserErrorWarning
-from tpcp.pipelines import OptimizablePipeline, SimplePipeline
 from tpcp.validation import Scorer
 from tpcp.validation._scorer import _ERROR_SCORE_TYPE, _validate_scorer
 
